==> huaweicloudsdkiotda-3.1.63-py2.py3-none-any.whl: huaweicloudsdkiotda/v5/model/connect_state.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ConnectState:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'last_update_time': 'str',
        'status': 'str'
    }

    attribute_map = {
        'last_update_time': 'last_update_time',
        'status': 'status'
    }

    def __init__(self, last_update_time=None, status=None):
        """ConnectState

        The model defined in huaweicloud sdk

        :param last_update_time: 隧道最近一次状态更新时间。格式：yyyyMMdd&#39;T&#39;HHmmss&#39;Z&#39;，如20151212T121212Z。
        :type last_update_time: str
        :param status: 客户端连接状态 CONNECTED | DISCONNECTED
        :type status: str
        """
        
        

        self._last_update_time = None
        self._status = None
        self.discriminator = None

        if last_update_time is not None:
            self.last_update_time = last_update_time
        if status is not None:
            self.status = status

    @property
    def last_update_time(self):
        """Gets the last_update_time of this ConnectState.

        隧道最近一次状态更新时间。格式：yyyyMMdd'T'HHmmss'Z'，如20151212T121212Z。

        :return: The last_update_time of this ConnectState.
        :rtype: str
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this ConnectState.

        隧道最近一次状态更新时间。格式：yyyyMMdd'T'HHmmss'Z'，如20151212T121212Z。

        :param last_update_time: The last_update_time of this ConnectState.
        :type last_update_time: str
        """
        self._last_update_time = last_update_time

    @property
    def status(self):
        """Gets the status of this ConnectState.

        客户端连接状态 CONNECTED | DISCONNECTED

        :return: The status of this ConnectState.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ConnectState.

        客户端连接状态 CONNECTED | DISCONNECTED

        :param status: The status of this ConnectState.
        :type status: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotda-3.1.153-py2.py3-none-any.whl: huaweicloudsdkiotda/v5/model/connect_state.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ConnectState:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'last_update_time': 'str',
        'status': 'str'
    }

    attribute_map = {
        'last_update_time': 'last_update_time',
        'status': 'status'
    }

    def __init__(self, last_update_time=None, status=None):
        r"""ConnectState

        The model defined in huaweicloud sdk

        :param last_update_time: 隧道最近一次状态更新时间。格式：yyyyMMdd&#39;T&#39;HHmmss&#39;Z&#39;，如20151212T121212Z。
        :type last_update_time: str
        :param status: 客户端连接状态 CONNECTED | DISCONNECTED
        :type status: str
        """
        
        

        self._last_update_time = None
        self._status = None
        self.discriminator = None

        if last_update_time is not None:
            self.last_update_time = last_update_time
        if status is not None:
            self.status = status

    @property
    def last_update_time(self):
        r"""Gets the last_update_time of this ConnectState.

        隧道最近一次状态更新时间。格式：yyyyMMdd'T'HHmmss'Z'，如20151212T121212Z。

        :return: The last_update_time of this ConnectState.
        :rtype: str
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        r"""Sets the last_update_time of this ConnectState.

        隧道最近一次状态更新时间。格式：yyyyMMdd'T'HHmmss'Z'，如20151212T121212Z。

        :param last_update_time: The last_update_time of this ConnectState.
        :type last_update_time: str
        """
        self._last_update_time = last_update_time

    @property
    def status(self):
        r"""Gets the status of this ConnectState.

        客户端连接状态 CONNECTED | DISCONNECTED

        :return: The status of this ConnectState.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        r"""Sets the status of this ConnectState.

        客户端连接状态 CONNECTED | DISCONNECTED

        :param status: The status of this ConnectState.
        :type status: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
